@@ -45,39 +45,11 @@ def cli():
 @click.option('--url',
               default='https://api.portico.org/kbart/Portico_Holding_KBart.txt',
               help='The URL to fetch')
+@click.option('--local', is_flag=True, default=False)
 @transaction.atomic()
-def import_portico(url):
+def import_portico(url, local):
     """Download and import data from Portico"""
-    log.info('[green]Downloading:[/] Portico data', extra={'markup': True})
-    csv_file = requests.get(url)
-
-    # clear out
-    log.info('[green]Clearing:[/] previous Portico data',
-             extra={'markup': True})
-    PorticoPreservation.objects.all().delete()
-
-    # increase the CSV field size to accommodate large entries
-    csv.field_size_limit(sys.maxsize)
-
-    with StringIO(csv_file.text) as input_file:
-        csv_reader = DictReader(input_file, delimiter='\t',
-                                quoting=csv.QUOTE_NONE)
-
-        for row in csv_reader:
-            publisher, created = \
-                Publisher.objects.get_or_create(name=row['publisher_name'])
-
-            PorticoPreservation.objects.create(
-                issn=row['print_identifier'], eissn=row['online_identifier'],
-                title=row['publication_title'],
-                preserved_volumes=row['holding_list'],
-                preserved=(row['notes'] == 'Preserved'),
-                publisher=publisher
-            )
-
-            log.info('[green]Added:[/] {} to '
-                     'Portico'.format(row['publication_title']),
-                     extra={'markup': True})
+    PorticoPreservation.import_data(url, local=local)
 
 
 @click.command()
@@ -95,39 +67,11 @@ def import_clockss(url, local):
 @click.option('--url',
               default='https://reports.lockss.org/keepers/keepers-LOCKSS-report.csv',
               help='The URL to fetch')
+@click.option('--local', is_flag=True, default=False)
 @transaction.atomic()
-def import_lockss(url):
+def import_lockss(url, local):
     """Download and import data from LOCKSS"""
-    log.info('[green]Downloading:[/] LOCKSS data', extra={'markup': True})
-    csv_file = requests.get(url)
-
-    # clear out
-    log.info('[green]Clearing:[/] previous LOCKSS data',
-             extra={'markup': True})
-    LockssPreservation.objects.all().delete()
-
-    with StringIO(csv_file.text) as input_file:
-        # skip the top line in the CSV which is something like
-        # #Keepers LOCKSS serials 2022-12-19
-        next(input_file)
-
-        csv_reader = DictReader(input_file)
-
-        for row in csv_reader:
-            publisher, created = \
-                Publisher.objects.get_or_create(name=row['Publisher'])
-
-            LockssPreservation.objects.create(
-                issn=row['ISSN'], eissn=row['eISSN'], title=row['Title'],
-                preserved_volumes=row['Preserved Volumes'],
-                preserved_years=row['Preserved Years'],
-                in_progress_volumes=row['In Progress Volumes'],
-                in_progress_years=row['In Progress Years'],
-                publisher=publisher
-            )
-
-            log.info('[green]Added:[/] {} to LOCKSS'.format(row['Title']),
-                     extra={'markup': True})
+    LockssPreservation.import_data(url, local=local)
 
 
 @click.command()
@@ -145,39 +89,11 @@ def import_pkp(url, local):
 @click.option('--url',
               default='http://reports-lockss.ibict.br/keepers/pln/ibictpln/keepers-IBICTPLN-report.csv',
               help='The URL to fetch')
+@click.option('--local', is_flag=True, default=False)
 @transaction.atomic()
-def import_cariniana(url):
+def import_cariniana(url, local):
     """Download and import data from Cariniana"""
-    log.info('[green]Downloading:[/] Cariniana data', extra={'markup': True})
-    csv_file = requests.get(url)
-
-    # clear out
-    log.info('[green]Clearing:[/] previous Cariniana data',
-             extra={'markup': True})
-    CarinianaPreservation.objects.all().delete()
-
-    with StringIO(csv_file.text) as input_file:
-        # skip the top line in the CSV which is something like
-        # #Keepers LOCKSS serials 2022-12-19
-        next(input_file)
-
-        csv_reader = DictReader(input_file)
-
-        for row in csv_reader:
-            publisher, created = \
-                Publisher.objects.get_or_create(name=row['Publisher'])
-
-            CarinianaPreservation.objects.create(
-                issn=row['ISSN'], eissn=row['eISSN'], title=row['Title'],
-                preserved_volumes=row['Preserved Volumes'],
-                preserved_years=row['Preserved Years'],
-                in_progress_volumes=row['In Progress Volumes'],
-                in_progress_years=row['In Progress Years'],
-                publisher=publisher
-            )
-
-            log.info('[green]Added:[/] {} to Cariniana'.format(row['Title']),
-                     extra={'markup': True})
+    CarinianaPreservation.import_data(url, local=local)
 
 
 def unpack_range(s):
