@@ -1,4 +1,8 @@
+import csv
+import logging
 import re
+import sys
+from io import StringIO
 
 from django.db import models, transaction
 
@@ -48,6 +52,44 @@ class LockssPreservation(models.Model):
         return utils.preservation_status(LockssPreservation, container_title,
                                          issn, volume, no=no)
 
+    @staticmethod
+    def create_preservation(issn, eissn, title, preserved_volumes,
+                            preserved_years, in_progress_volumes,
+                            in_progress_years, publisher, model) -> None:
+        """
+        Create a preservation item of this model
+        :param issn: the ISSN
+        :param eissn: the eISSN
+        :param title: the title
+        :param preserved_volumes: the preserved volumes
+        :param preserved_years: the preserved years
+        :param in_progress_volumes: the in-progress volumes
+        :param in_progress_years: the in-progress years
+        :param publisher: the publisher object
+        :param model: the model on which to operate
+        :return: None
+        """
+        model.objects.create(
+            issn=issn, eissn=eissn, title=title,
+            preserved_volumes=preserved_volumes,
+            preserved_years=preserved_years,
+            in_progress_volumes=in_progress_volumes,
+            in_progress_years=in_progress_years,
+            publisher=publisher
+        )
+
+    @staticmethod
+    @transaction.atomic
+    def import_data(url: str = None, local: bool = False) -> None:
+        """
+        Import data into the system
+        :param url: the URL of the data file
+        :param local: whether the data file is local
+        :return: None
+        """
+        utils.generic_lockss_import(url, LockssPreservation, local=local,
+                                    skip_first_line=True)
+
 
 class CarinianaPreservation(models.Model):
     class Meta:
@@ -81,6 +123,44 @@ class CarinianaPreservation(models.Model):
         return utils.preservation_status(CarinianaPreservation, container_title,
                                          issn, volume, no=no)
 
+    @staticmethod
+    def create_preservation(issn, eissn, title, preserved_volumes,
+                            preserved_years, in_progress_volumes,
+                            in_progress_years, publisher, model) -> None:
+        """
+        Create a preservation item of this model
+        :param issn: the ISSN
+        :param eissn: the eISSN
+        :param title: the title
+        :param preserved_volumes: the preserved volumes
+        :param preserved_years: the preserved years
+        :param in_progress_volumes: the in-progress volumes
+        :param in_progress_years: the in-progress years
+        :param publisher: the publisher object
+        :param model: the model on which to operate
+        :return: None
+        """
+        model.objects.create(
+            issn=issn, eissn=eissn, title=title,
+            preserved_volumes=preserved_volumes,
+            preserved_years=preserved_years,
+            in_progress_volumes=in_progress_volumes,
+            in_progress_years=in_progress_years,
+            publisher=publisher
+        )
+
+    @staticmethod
+    @transaction.atomic
+    def import_data(url: str = None, local: bool = False) -> None:
+        """
+        Import data into the system
+        :param url: the URL of the data file
+        :param local: whether the data file is local
+        :return: None
+        """
+        utils.generic_lockss_import(url, CarinianaPreservation, local=local,
+                                    skip_first_line=True)
+
 
 class ClockssPreservation(models.Model):
     class Meta:
@@ -315,3 +395,41 @@ class PorticoPreservation(models.Model):
                 return pi, pi.preserved
 
         return None, False
+
+    @staticmethod
+    @transaction.atomic
+    def import_data(url: str = None, local: bool = False) -> None:
+        """
+        Import data into the system
+        :param url: the URL of the data file
+        :param local: whether the data file is local
+        :return: None
+        """
+        # get CSV data
+        csv_file = utils.download_remote(local, PorticoPreservation, url)
+
+        # clear out
+        utils.clear_out(PorticoPreservation)
+
+        # increase the CSV field size to accommodate large entries
+        csv.field_size_limit(sys.maxsize)
+
+        with StringIO(csv_file.text) as input_file:
+            csv_reader = csv.DictReader(input_file, delimiter='\t',
+                                        quoting=csv.QUOTE_NONE)
+
+            for row in csv_reader:
+                publisher, created = \
+                    Publisher.objects.get_or_create(name=row['publisher_name'])
+
+                PorticoPreservation.objects.create(
+                    issn=row['print_identifier'],
+                    eissn=row['online_identifier'],
+                    title=row['publication_title'],
+                    preserved_volumes=row['holding_list'],
+                    preserved=(row['notes'] == 'Preserved'),
+                    publisher=publisher
+                )
+
+                logging.info(f'Added {row["Title"]} to '
+                             f'{PorticoPreservation.name()} data')
