@@ -8,8 +8,9 @@ from crossref.restful import Etiquette, Works
 from django.db.models import QuerySet
 
 
-def show_preservation(container_title: str, issn: str, volume: str, no: str,
-                      doi: str, archive: str = None) -> (dict | None, str):
+def show_preservation(container_title: str, issn: str, volume: str,
+                      no: str | None, doi: str,
+                      archive: str = None) -> (dict | None, str):
     """
     Determine whether an item is preserved
     :param container_title: the journal/container name
@@ -94,18 +95,11 @@ def generic_lockss_import(url: str, model,
     """
     from preservationdatabase.models import Publisher
 
-    if not local:
-        logging.info(f'Downloading: {model.name()} data')
-        csv_file = requests.get(url).text
-    else:
-        logging.info(f'Using local file for {model.name()} data')
-
-        with open(url, 'r') as f:
-            csv_file = f.read()
+    # get CSV data
+    csv_file = download_remote(local, model, url)
 
     # clear out
-    logging.info(f'Clearing previous {model.name()} data')
-    model.objects.all().delete()
+    clear_out(model)
 
     with StringIO(csv_file) as input_file:
         # skip the top line in the CSV which is something like
@@ -119,7 +113,8 @@ def generic_lockss_import(url: str, model,
             publisher, created = \
                 Publisher.objects.get_or_create(name=row['Publisher'])
 
-            if model.name() == 'CLOCKSS':
+            if model.name() == 'CLOCKSS' or model.name() == 'LOCKSS'\
+                    or model.name() == 'Cariniana':
                 # create the item
                 model.create_preservation(
                     issn=row['ISSN'], eissn=row['eISSN'], title=row['Title'],
@@ -140,6 +135,23 @@ def generic_lockss_import(url: str, model,
             logging.info(f'Added {row["Title"]} to {model.name()} data')
 
 
+def clear_out(model):
+    logging.info(f'Clearing previous {model.name()} data')
+    model.objects.all().delete()
+
+
+def download_remote(local, model, url):
+    if not local:
+        logging.info(f'Downloading: {model.name()} data')
+        csv_file = requests.get(url).text
+    else:
+        logging.info(f'Using local file for {model.name()} data')
+
+        with open(url, 'r') as f:
+            csv_file = f.read()
+    return csv_file
+
+
 def preservation_status(model, container_title, issn, volume,
                         no=None) -> (dict | None, str):
     """
